<?php

namespace EventPortal\Tests\Unit\Util;

use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Util\CombinedValidation;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class CombinedValidationTest extends TestCase
{
    use DatabaseMigrations;

    /** @test **/
    public function get_validation_for_array()
    {
        $field = [
            'validation' => [
                'required',
            ],
            'updateValidation' => [
                'email',
            ],
            'createValidation' => [
                'min:2',
                'max:10',
            ],
        ];

        $this->assertEquals(
            ['required', 'min:2', 'max:10'],
            CombinedValidation::get($field, 'create')
        );

        $this->assertEquals(
            ['required', 'email'],
            CombinedValidation::get($field, 'update')
        );
    }

    /** @test **/
    public function get_validation_for_model()
    {
        $validation = [
            'validation' => [
                'required',
            ],
            'updateValidation' => [
                'email',
            ],
            'createValidation' => [
                'min:2',
                'max:10',
            ],
        ];

        $field = factory(Field::class)->create(['data' => $validation]);

        $this->assertEquals(
            ['required', 'min:2', 'max:10'],
            CombinedValidation::get($field, 'create')
        );

        $this->assertEquals(
            ['required', 'email'],
            CombinedValidation::get($field, 'update')
        );
    }
}
